<?php
namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\WelcomeMessage;
use App\Language;
use Storage;

class BoasvindasController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $languages = Language::latest()->paginate(5);

        $data = compact('languages');

        return $this->view('boasvindas.index', $data)
            ->with('i', (request()->input('page', 1) - 1) * 5); 
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $languages = Language::all();

        $cidades            =           City::all();

        $data = compact('languages', 'cidades', 'rota');

        return $this->view('rotas.create', $data);
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $languages = Language::all();

        $rota           =       new Route;
        $rota->city_id  =       $request->city_id;
        $rota->save(); 

        foreach ($languages as $language) {

            request()->validate([
                'name.' . $language->slug => 'required'
            ]);

            request()->validate([
                'description.' . $language->slug => 'required'
            ]);

            $message = RouteContent::where('route_id', '=', $rota->id)->where('language_id', '=', $language->id)->first();
            if (!$message) {
                $message = new RouteContent;
            }

         
            $message->route_id = $rota->id;
            $message->language_id = $language->id;
            $message->name = $request->name[$language->slug];
            $message->description = $request->description[$language->slug];
            $message->save();
        }

        return redirect()->route('admin.rotas.index') 
            ->with('success', 'Criado com sucesso');
    }


    /**
     * Display the specified resource.
     *
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function show(Historico $historico)
    {
        return $this->view('boasvindas.show', compact('historico'));
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request, $language_id)
    {
        $language = Language::find($language_id);

        $message = WelcomeMessage::where('language_id', '=', $language->id)->first(); 

        $data = compact('message', 'language');

        return $this->view('boasvindas.edit', $data); 
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $language_id)
    {
        $language = Language::find($language_id);

        $message = WelcomeMessage::where('language_id', '=', $language->id)->first();

        if (!$message) {
            $message = new WelcomeMessage;
        }

        if($request->file('audio_message')){
            $path = Storage::putFile('audio/boasvidas', $request->file('audio_message'));
            $message->audio_message = $path;
        }

        $message->language_id = $language->id;
        $message->text_message = $request->text_message;
        $message->save();

        return redirect()->route('admin.boasvindas.index') 
            ->with('success', 'Atualizado com sucesso');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function destroy(Historico $historico)
    {
        $historico->delete();


        return redirect()->route('admin.boasvindas.index')
            ->with('success', 'Deletado com sucesso');
    }
}