<?php
namespace App\Http\Controllers\Admin;

use App\City as Cidade;
use App\Country;
use Illuminate\Http\Request;
use Storage;

class CidadeController extends Controller 
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $cidades = Cidade::with('country')->latest()->paginate(5);


        return $this->view('cidades.index',compact('cidades'))
            ->with('i', (request()->input('page', 1) - 1) * 5); 
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $countries              =           Country::all();

        $data = compact('countries');
        return $this->view('cidades.create', $data);
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate([
            'name' => 'required',
        ]);


        $cidade = new Cidade;
        $cidade->cover = Storage::putFile('cover/city', $request->file('cover'));
        $cidade->country_id = $request->country_id;
        $cidade->name = $request->name;
        $cidade->save();


        return redirect()->route('admin.cidades.index')
                        ->with('success','Criado com sucesso.');
    }


    /**
     * Display the specified resource.
     *
     * @param  \App\Cidade  $cidade
     * @return \Illuminate\Http\Response
     */
    public function show(Cidade $cidade)
    {
        return $this->view('cidades.show',compact('cidade'));
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Cidade  $cidade
     * @return \Illuminate\Http\Response
     */
    public function edit(Cidade $cidade)
    {
        $cidade         =       Cidade::with('country')->find($cidade->id);
        $countries              =           Country::all();

        $data = compact('countries', 'cidade');

        return $this->view('cidades.edit', $data);
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Cidade  $cidade
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Cidade $cidade)
    {
         request()->validate([
            'name' => 'required',
        ]);

        $cidade = Cidade::find($cidade->id);
       
  
        if($request->cover){
            $cidade->cover = Storage::putFile('cover/city', $request->file('cover'));
        }
        $cidade->country_id = $request->country_id;
        $cidade->name = $request->name;
        $cidade->save();

   

        return redirect()->route('admin.cidades.index')
                        ->with('success','Atualizado com sucesso');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Cidade  $cidade
     * @return \Illuminate\Http\Response
     */
    public function destroy(Cidade $cidade)
    {
        $cidade->delete();


        return redirect()->route('admin.cidades.index')
                        ->with('success','Deletado com sucesso');
    }
}