<?php
namespace App\Http\Controllers\Admin;

use App\CityHistory as Historico;
use App\City as Cidade;
use Illuminate\Http\Request;
use App\Language;
use Storage;

class HistoricoController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $cidades = Cidade::latest()->paginate(5);


        return $this->view('historicos.index', compact('cidades'))
            ->with('i', (request()->input('page', 1) - 1) * 5);
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $languages = Language::all();
        $cidades = Cidade::doesnthave('city_histories')->get();

        $data = compact('languages', 'cidades');

        return $this->view('historicos.create', $data);
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $languages = Language::all();

        foreach ($languages as $language) {

            request()->validate([
                'text_message.' . $language->slug => 'required'
            ]);

            request()->validate([
                'audio_message.' . $language->slug => 'required'
            ]);

            

            $history = Historico::where('city_id', '=', $request->city_id)->where('language_id', '=', $language->id)->first();
            if (!$history) {
                $history = new Historico;
            }

            $path = Storage::putFile('audio/city', $request->file('audio_message.' . $language->slug));


            $history->city_id = $request->city_id;
            $history->language_id = $language->id;
            $history->text_message = $request->text_message[$language->slug];
            $history->audio_message = $path;
            $history->save();
        }

        return redirect()->route('admin.historicos.index')
            ->with('success', 'Atualizado com sucesso'); 
    }


    /**
     * Display the specified resource.
     *
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function show(Historico $historico)
    {
        return $this->view('historicos.show', compact('historico'));
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request, $city_id)
    {
        $languages = Language::all();

        $cidades = Cidade::has('city_histories')->get();

        foreach ($languages as $language) {
            $language->data_historico = Historico::where('city_id', '=', $city_id)->where('language_id', '=', $language->id)->first();
        }

        $data = compact('city_id', 'languages', 'cidades');

        return $this->view('historicos.edit', $data);
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $city_id)
    {

        $languages = Language::all();
      
        foreach ($languages as $language) {

            request()->validate([
                'text_message.' . $language->slug => 'required'
            ]);

            //request()->validate([
            //    'audio_message.' . $language->slug => 'required'
            //]);

            $history = Historico::where('city_id', '=', $city_id)->where('language_id', '=', $language->id)->first();
            if (!$history) {
                $history = new Historico;
            }

            if($request->file('audio_message.' . $language->slug)){
                $path = Storage::putFile('audio/city', $request->file('audio_message.' . $language->slug));
                $history->audio_message = $path;
            }

            $history->city_id = $city_id;
            $history->language_id = $language->id;
            $history->text_message = $request->text_message[$language->slug];
            $history->save();
        }

        return redirect()->route('admin.historicos.index')
            ->with('success', 'Atualizado com sucesso');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Historico  $historico
     * @return \Illuminate\Http\Response
     */
    public function destroy(Historico $historico)
    {
        $historico->delete();


        return redirect()->route('admin.historicos.index')
            ->with('success', 'Deletado com sucesso');
    }
}